@@ -12,11 +12,12 @@ pub enum SqlType {
     InsertInto,
     DeleteFrom,
     Update,
+    Query,
 }
 
 #[derive(Debug, PartialEq, Eq)]
 pub struct Statement {
-    pub target: String,
+    pub target: Option<String>,
     pub kind: SqlType,
     pub sources: HashSet<String>,
 }
@@ -72,60 +73,44 @@ fn from_statement(statement: &ast::Statement) -> Option<Statement> {
             ..
         } => {
             let sources = from_query(query);
-            if sources.is_empty() {
-                None
-            } else {
-                let target = from_object_name(name);
-                Some(Statement {
-                    target,
-                    sources: HashSet::from_iter(sources),
-                    kind: SqlType::CreateTable,
-                })
-            }
+            let target = from_object_name(name);
+            Some(Statement {
+                target: Some(target),
+                sources: HashSet::from_iter(sources),
+                kind: SqlType::CreateTable,
+            })
         }
         ast::Statement::CreateView { name, query, .. } => {
             let sources = from_query(query);
-            if sources.is_empty() {
-                None
-            } else {
-                let target = from_object_name(name);
-                Some(Statement {
-                    target,
-                    sources: HashSet::from_iter(sources),
-                    kind: SqlType::CreateView,
-                })
-            }
+            let target = from_object_name(name);
+            Some(Statement {
+                target: Some(target),
+                sources: HashSet::from_iter(sources),
+                kind: SqlType::CreateView,
+            })
         }
         ast::Statement::Insert {
             table_name, source, ..
         } => {
             let sources = from_query(source);
-            if sources.is_empty() {
-                None
-            } else {
-                let target = from_object_name(table_name);
-                Some(Statement {
-                    target,
-                    sources: HashSet::from_iter(sources),
-                    kind: SqlType::InsertInto,
-                })
-            }
+            let target = from_object_name(table_name);
+            Some(Statement {
+                target: Some(target),
+                sources: HashSet::from_iter(sources),
+                kind: SqlType::InsertInto,
+            })
         }
         ast::Statement::Delete {
             table_name,
             selection: Some(selection),
         } => {
             let sources = from_expr(selection);
-            if sources.is_empty() {
-                None
-            } else {
-                let target = from_object_name(table_name);
-                Some(Statement {
-                    target,
-                    sources: HashSet::from_iter(sources),
-                    kind: SqlType::DeleteFrom,
-                })
-            }
+            let target = from_object_name(table_name);
+            Some(Statement {
+                target: Some(target),
+                sources: HashSet::from_iter(sources),
+                kind: SqlType::DeleteFrom,
+            })
         }
         ast::Statement::Update {
             table,
@@ -141,16 +126,31 @@ fn from_statement(statement: &ast::Statement) -> Option<Statement> {
             if let Some(selection) = selection {
                 sources.extend(from_expr(selection));
             }
-            if sources.is_empty() {
-                None
-            } else {
-                Some(Statement {
-                    target,
-                    sources: HashSet::from_iter(sources),
-                    kind: SqlType::Update,
-                })
-            }
+            Some(Statement {
+                target: Some(target),
+                sources: HashSet::from_iter(sources),
+                kind: SqlType::Update,
+            })
         }
+        ast::Statement::Query(query) => {
+            let sources = from_query(query);
+            let target = select_into(query);
+            Some(Statement {
+                target,
+                sources: HashSet::from_iter(sources),
+                kind: SqlType::Query,
+            })
+        }
+        _ => None,
+    }
+}
+
+fn select_into(query: &ast::Query) -> Option<String> {
+    match &query.body {
+        ast::SetExpr::Select(select) => match &select.into {
+            Some(select_into) => Some(from_object_name(&select_into.name)),
+            None => None,
+        },
         _ => None,
     }
 }
@@ -409,27 +409,27 @@ mod tests {
             statements,
             vec![
                 Statement {
-                    target: "a.foo".into(),
+                    target: Some("a.foo".into()),
                     kind: SqlType::CreateView,
                     sources: HashSet::from_iter(vec!["a.bar".into()]),
                 },
                 Statement {
-                    target: "b.foo".into(),
+                    target: Some("b.foo".into()),
                     kind: SqlType::CreateTable,
                     sources: HashSet::from_iter(vec!["b.bar".into()]),
                 },
                 Statement {
-                    target: "c.foo".into(),
+                    target: Some("c.foo".into()),
                     kind: SqlType::InsertInto,
                     sources: HashSet::from_iter(vec!["c.bar".into()]),
                 },
                 Statement {
-                    target: "d.foo".into(),
+                    target: Some("d.foo".into()),
                     kind: SqlType::DeleteFrom,
                     sources: HashSet::from_iter(vec!["d.bar".into()]),
                 },
                 Statement {
-                    target: "e.foo".into(),
+                    target: Some("e.foo".into()),
                     kind: SqlType::Update,
                     sources: HashSet::from_iter(vec!["e.bar".into()]),
                 },
@@ -449,7 +449,7 @@ mod tests {
         assert_eq!(
             statements,
             vec![Statement {
-                target: "foo".into(),
+                target: Some("foo".into()),
                 kind: SqlType::CreateView,
                 sources: HashSet::from_iter(vec!["bar".into(), "baz".into()]),
             }],
@@ -474,7 +474,7 @@ mod tests {
         assert_eq!(
             statements,
             vec![Statement {
-                target: "foo".into(),
+                target: Some("foo".into()),
                 kind: SqlType::InsertInto,
                 sources: HashSet::from_iter(vec!["bar".into(), "baz".into()]),
             }],
@@ -497,7 +497,7 @@ mod tests {
         assert_eq!(
             statements,
             vec![Statement {
-                target: "foo".into(),
+                target: Some("foo".into()),
                 kind: SqlType::InsertInto,
                 sources: HashSet::from_iter(vec!["bar".into()]),
             }],
@@ -516,7 +516,7 @@ mod tests {
         assert_eq!(
             statements,
             vec![Statement {
-                target: "foo".into(),
+                target: Some("foo".into()),
                 kind: SqlType::CreateTable,
                 sources: HashSet::from_iter(vec!["bar".into()]),
             }],
@@ -536,7 +536,7 @@ mod tests {
         assert_eq!(
             statements,
             vec![Statement {
-                target: "a.foo".into(),
+                target: Some("a.foo".into()),
                 kind: SqlType::CreateView,
                 sources: HashSet::from_iter(vec!["b.bar".into(), "c.baz".into()]),
             }],
@@ -549,20 +549,52 @@ mod tests {
             drop table foo;
             create table foo as
             select * from bar;
-            delete from foo
-            where foo_id = 1;
         ";
         let statements = parse_statements(sql, Dialect::Postgres).unwrap();
         assert_eq!(
             statements,
             vec![Statement {
-                target: "foo".into(),
+                target: Some("foo".into()),
                 kind: SqlType::CreateTable,
                 sources: HashSet::from_iter(vec!["bar".into()]),
             }],
         );
     }
 
+    #[test]
+    fn select_into() {
+        let sql = "
+            select * into foo
+            from bar;
+        ";
+        let statements = parse_statements(sql, Dialect::Postgres).unwrap();
+        assert_eq!(
+            statements,
+            vec![Statement {
+                target: Some("foo".into()),
+                kind: SqlType::Query,
+                sources: HashSet::from_iter(vec!["bar".into()]),
+            }],
+        );
+    }
+
+    #[test]
+    fn plain_query() {
+        let sql = "
+            select *
+            from foo;
+        ";
+        let statements = parse_statements(sql, Dialect::Postgres).unwrap();
+        assert_eq!(
+            statements,
+            vec![Statement {
+                target: None,
+                kind: SqlType::Query,
+                sources: HashSet::from_iter(vec!["foo".into()]),
+            }],
+        );
+    }
+
     #[test]
     fn kitchen_sink() {
         let sql = "
@@ -586,7 +618,7 @@ mod tests {
             union all
             select * from orig.bar;
 
-            delete from baz where delete_flag = 1;
+            drop table baz;
 
             insert into baz
             select bar_alias.*,
@@ -605,22 +637,22 @@ mod tests {
             statements,
             vec![
                 Statement {
-                    target: "foo".into(),
+                    target: Some("foo".into()),
                     kind: SqlType::CreateTable,
                     sources: HashSet::from_iter(vec!["orig.foo".into()]),
                 },
                 Statement {
-                    target: "bar".into(),
+                    target: Some("bar".into()),
                     kind: SqlType::CreateView,
                     sources: HashSet::from_iter(vec!["foo".into(), "orig.bar".into()]),
                 },
                 Statement {
-                    target: "baz".into(),
+                    target: Some("baz".into()),
                     kind: SqlType::InsertInto,
                     sources: HashSet::from_iter(vec!["bar".into(), "qux".into()]),
                 },
                 Statement {
-                    target: "foo".into(),
+                    target: Some("foo".into()),
                     kind: SqlType::DeleteFrom,
                     sources: HashSet::from_iter(vec!["bar".into()]),
                 },
